data "aws_db_instance" "database" {
  count = var.connection_enabled == true && var.connection_type == "JDBC" ? 1 : 0
  db_instance_identifier = var.rds_instance_name
}

data "aws_db_subnet_group" "database_subnet_group" {
  count = var.connection_enabled == true && var.connection_type == "JDBC" ? 1 : 0
  name  = data.aws_db_instance.database[0].db_subnet_group
}

resource "aws_glue_connection" "glue_connection" {
  count              = var.connection_enabled == true ? 1 : 0
  name               = "${var.glue_job_name}-connection"
  connection_type    = var.connection_type

  connection_properties = {
    JDBC_CONNECTION_URL = var.connection_type == "JDBC" ? var.jdbc_url : null,
    USERNAME            = var.connection_type == "JDBC" ? var.db_username : null,
    PASSWORD            = var.connection_type == "JDBC" ? var.db_password : null
  }

  physical_connection_requirements {
    availability_zone = var.connection_type == "JDBC" ? data.aws_db_instance.database[0].availability_zone : var.availability_zone
    security_group_id_list = var.connection_type == "JDBC" ? data.aws_db_instance.database[0].vpc_security_groups : var.security_group_id_list
    subnet_id = var.connection_type == "JDBC" ? element(tolist(data.aws_db_subnet_group.database_subnet_group[0].subnet_ids), 0) : var.subnet_id
  }
}