#---------------------------------------------------
# Glue Job Variables
#---------------------------------------------------
variable "glue_job_name" {
  type        = string
  description = "Name of the glue job."
}
variable "glue_job_role_arn" {
  type        = string
  description = "Role Arn assumed by the glue job"
}
variable "glue_job_role_name" {
  type        = string
  description = "Name of the glue job role"
}
variable "glue_job_description" {
  type        = string
  description = "Brief Description of the glue job"
}
variable "glue_job_arguments" {
  type        = map(string)
  description = "Arguments used by the glue job."
  default = {}
}
variable "glue_job_version" {
  type        = string
  description = "The version of glue to use, for example '1.0'. For information about available versions, see the AWS Glue Release Notes."
}
variable "glue_job_max_capacity" {
  type        = any
  default     = null
  description = "The number of AWS Glue data processing units (DPUs) that can be allocated when this job runs. A DPU is a relative measure of processing power that consists of 4 vCPUs of compute capacity and 16 GB of memory."
}
variable "glue_job_max_retries" {
  type        = string
  description = "The maximum number of times to retry this job after a JobRun fails."
}
variable "glue_job_worker_type" {
  type        = any
  default     = null
  description = "The type of predefined worker that is allocated when a job runs. Accepts a value of Standard, G.1X, or G.2X"
}
variable "glue_job_number_of_workers" {
  type        = any
  default     = null
  description = "The number of workers of a defined workerType that are allocated when a job runs."
}
variable "glue_job_script_location" {
  type        = string
  description = "A map of a on_demand_trigger parameters. Includs target job name."
}
variable "glue_job_command_name" {
  type        = string
  description = "The name of the job command. For an Apache Spark ETL job, this must be glueetl. For a Python shell job, it must be pythonshell."
}
variable "python_version" {
  type        = string
  description = "The Python version being used to execute a Python shell job. Allowed values are 2 or 3."
  default     = ""
}
variable "glue_job_max_concurrent_runs" {
  type        = string
  description = "The maximum number of concurrent runs allowed for a job."
}
variable "glue_job_delay_notification_threshold" {
  type        = string
  description = "After a job run starts, the number of minutes to wait before sending a job run delay notification."
}
variable "glue_job_timeout" {
  type        = string
  description = "The job timeout in minutes. The default is 2880 minutes (48 hours).."
}
variable "iam_policy_prefix" {
  type = string
}
#---------------------------------------------------
# Glue Job Event Rule Variables
#---------------------------------------------------
variable "create_event_rule" {
  type        = bool
  description = "Decides if an event rule needs to be created for the glue job (defaults to false)"
  default     = false
}
variable "enable_event_rule" {
  type        = bool
  description = "Whether the rule should be enabled (defaults to true)"
  default     = true
}
variable "glue_job_alert_states" {
  type        = any
  description = "List of states of a glue job which will trigger a CW event when it changes (Allowed values are STARTING, RUNNING, STOPPING, STOPPED, SUCCEEDED, FAILED, ERROR, and TIMEOUT)"
  default     = []
}
variable "target_arn" {
  type        = string
  description = "Arn of the cloudwatch event target (only and supported)"
  default     = ""
}

# https://confluence.carbonblack.local/display/cbengx/SBU+AWS+Tagging+Policy
variable "tags" {
  description = "A mapping of tags to assign to the resource"
  type        = map(string)
}

variable "schedule" {
  type        = string
  description = "Custom schedule when you want to run this gluejob."
}

#---------------------------------------------------
# AWS Glue connection
#---------------------------------------------------
variable "connection_enabled" {
  type    = bool
  default = false
}

variable "connection_type" {
  description = "The type of the connection. Supported are: JDBC and NETWORK"
  type        = string
  default     = ""
}

# variables when glue connection type is JDBC
variable "jdbc_url" {
  type        = string      
  description = "JDBC url for the glue connection"
  default = ""
}

variable "db_username" {
  type        = string
  description = "Database user to be used by the glue connection."
  default     = ""
}

variable "db_password" {
  type        = string
  description = "Database paasword to be used by the glue conenction."
  default     = false
}

variable "rds_instance_name" {
  type        = string
  description = "Aurora RDS Database instance name"
  default = ""
}

# variables when glue connection type is NETWORK
variable "availability_zone" {
  type        = string
  description = "availability_zone details for Glue connection."
  default     = ""
}

variable "security_group_id_list" {
  type        = list
  description = "Security group IDs for Glue connection."
  default     = []
}

variable "subnet_id" {
  type        = string
  description = "Subnet IDs for Glue connection."
  default = ""
}
